"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * © 2013 Liferay, Inc. <https://liferay.com> and Node GH contributors
 * (see file: README.md)
 * SPDX-License-Identifier: BSD-3-Clause
 */
const utils_1 = require("../../utils");
const immer_1 = require("immer");
const logger = require("../../logger");
function newIssue(options) {
    options = immer_1.produce(options, draft => {
        if (draft.labels) {
            draft.labels = draft.labels.split(',');
        }
        else {
            draft.labels = [];
        }
        if (draft.message) {
            draft.message = logger.applyReplacements(draft.message, draft.config.replace);
        }
        if (utils_1.userLeftMsgEmpty(draft.title)) {
            draft.title = utils_1.openFileInEditor('temp-gh-issue-title.txt', '# Add a issue title message on the next line');
        }
        // If user passes an empty title and message, --message will get merged into options.title
        // Need to reference the original title not the potentially modified one
        if (utils_1.userLeftMsgEmpty(options.title) || utils_1.userLeftMsgEmpty(draft.message)) {
            draft.message = utils_1.openFileInEditor('temp-gh-issue-body.md', '<!-- Add an issue body message in markdown format below -->');
        }
    });
    const payload = {
        body: options.message,
        assignee: options.assignee,
        repo: options.repo,
        title: options.title,
        owner: options.user,
        labels: options.labels,
    };
    return options.GitHub.issues.create(payload);
}
exports.newIssue = newIssue;
//# sourceMappingURL=new.js.map